-- Reloader: Kills all plugins but itself and restarts Bootstrap.

import "Turbine.UI.Lotro";

local reload = function()
	Turbine.Shell.WriteLine( "Bootstrap: Reloading" );

	local scriptStates = {}
	local turbinePlugins = Turbine.PluginManager.GetLoadedPlugins();

	-- Find all different script states
	for k,turbinePlugin in pairs( turbinePlugins ) do
		if turbinePlugin.ScriptState ~= "BootstrapReloader" then
			scriptStates[turbinePlugin.ScriptState] = true;
		end
	end

	-- Unload them all
	for scriptState, v in pairs( scriptStates ) do
		Turbine.PluginManager.UnloadScriptState( scriptState );
	end

	-- resets the UI for those plugins that might have hooked bags or whatever
	Turbine.UI.Lotro.LotroUI.Reset();

	-- Relaunch Bootstrap
	Turbine.PluginManager.LoadPlugin( "Bootstrap" );

	-- And we're done. Bootstrap should unload this script when it starts
end

-- UnloadScriptState() can't unload the script state from which we were loaded if we haven't returned first
-- so we defer reloading to the next GUI update event using a control
local control = Turbine.UI.Control();
control:SetWantsUpdates( true );
control.Update = function( sender, args ) 
	reload();
	control:SetWantsUpdates(false); -- we really really don't want another udpate
end